@@ -29,7 +29,7 @@ def get_coordinates(elements,i):
             
 def create_GeoJson_Lines(elements):    
     """
-    create GeoJSON output if Netz.elements consists of points
+    create GeoJSON output if Netz.elements consists of lines
     """    
     feature=[]
     for i in range(len(elements)):
@@ -73,8 +73,9 @@ def geojson_export_element(Netz,Elementtyp,verbose=False):
     Export Netz.Element to a geoJSON file
     """
     elements=Netz.__dict__.get(Elementtyp)
-    if verbose==True:
-        print(elements)
+    #if verbose:
+     #   print(elements)
+      #  print(Elementtyp)
     if Elementtyp in (['PipeLines','PipeSegments']):
         output=json.dumps({'type': 'FeatureCollection',
           'features': create_GeoJson_Lines(elements)},indent=4)
@@ -89,21 +90,22 @@ def export_geojson(Netz,netname,filepath='Output/GeoJSON/',verbose=False):
     Export Netz object to separate geojson files
     """
     
-    for pipe in Netz.PipeLines:
+    for pipe in Netz.PipeSegments:
         pipe.country_code=list(pipe.country_code)
-    
-    print(os.path.dirname(filepath))
-    print(os.path.exists(os.path.dirname(filepath)))
+    if verbose:
+        print(os.path.dirname(filepath))    
+        print('Filepathexist=',os.path.exists(os.path.dirname(filepath)))   
     if not os.path.exists(os.path.dirname(filepath)):
         os.makedirs(os.path.dirname(filepath))
-        if (verbose==True):
+        if verbose:
             print('created the following path: ', filepath)
         time.sleep(10)
-        if (verbose==True):
+        if verbose:
             print(os.path.exists(os.path.dirname(filepath)))
         
     if os.path.exists(os.path.dirname(filepath)):
-        for elementname in Netz.CompLabels():
+        for elementname in Netz.CompLabels():   
+            if verbose: print(elementname)
             if len(Netz.__dict__[elementname])>0:
                 a=geojson_export_element(Netz,elementname,verbose)
                 filename=netname+'_'+elementname+'.geojson'
